# Copyright Collab 2015-2016
# See LICENSE for details.

"""
Admin footer template tag.
"""

from datetime import datetime

from django import template
from django.conf import settings
from django.template import base, loader


register = template.Library()


class AdminFooterNode(template.Node):
    """
    Build footer and render the resulting context into the template.
    """
    def render(self, context):
        data = getattr(settings, 'ADMIN_FOOTER_DATA', {
            'period': datetime.now().year
        })
        if context['request'].user.is_staff is False:
            data.pop('version', None)

        tpl = loader.get_template('admin_footer/footer.html')
        return tpl.render(data)


@register.tag
def admin_footer(parser, token):
    """
    Template tag that renders the footer information based on the
    authenticated user's permissions.
    """
    # split_contents() doesn't know how to split quoted strings.
    tag_name = token.split_contents()

    if len(tag_name) > 1:
        raise base.TemplateSyntaxError(
            '{} tag does not accept any argument(s): {}'.format(
            token.contents.split()[0],
            ', '.join(token.contents.split()[1:])
    ))

    return AdminFooterNode()



# Copyright Collab 2015-2016
# See LICENSE for details.

"""
`django-admin-footer` application.
"""

from __future__ import unicode_literals


#: Application version.
__version__ = (1, 0, 0)


def short_version(version=None):
    """
    Return short application version. For example: `1.0.0`.
    """
    v = version or __version__
    return '.'.join([str(x) for x in v[:3]])


def get_version(version=None):
    """
    Return full version nr, inc. rc, beta etc tags.

    For example: `2.0.0a1`
    :rtype: str
    """
    v = version or __version__
    if len(v) == 4:
        return '{0}{1}'.format(short_version(v), v[3])

    return short_version(v)


#: Full version number.
version = get_version()



# Copyright Collab 2015-2016
# See LICENSE for details.

import os
from datetime import datetime

from admin_footer import version


SITE_ID = 1

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    }
}

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': True
    },
]

INSTALLED_APPS = [
    'django.contrib.auth',
    'django.contrib.sessions',
    'django.contrib.contenttypes',
    'django.contrib.admin',
    'admin_footer'
]

# =============================================================================
# ADMIN FOOTER
# =============================================================================

ADMIN_FOOTER_DATA = {
    'site_url': 'https://www.example.com',
    'site_name': 'MyCompany',
    'period': '2015-{}'.format(datetime.now().year),
    'version': 'v{} - '.format(version)
}

ROOT_URLCONF = 'admin_footer.tests.urls'

SECRET_KEY = 'top_secret'

LOCAL_FILE_STORAGE = 'django.core.files.storage.FileSystemStorage'

STATIC_URL = '/static/'

MEDIA_ROOT = os.path.abspath('media')

# A tuple of directories where Django looks for translation files.
LOCALE_PATHS = (
    os.path.join(os.path.abspath('../locale')),
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
)

# Logging configuration.
# See https://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.

LOG_HANDLER = 'null'

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'formatters': {
        'simple': {
            'format': '%(asctime)s %(levelname)-6s %(name)-15s - %(message)s'
        },
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'simple',
        },
        'null': {
            'level': 'DEBUG',
            'class': 'logging.NullHandler',
        }
    },
    'loggers': {
        'admin_footer': {
            'handlers': [LOG_HANDLER],
            'level': 'DEBUG'
        },
    }
}



# Copyright Collab 2015-2016
# See LICENSE for details.

"""
URLConf for :py:mod:`admin_footer` tests.
"""

from django.contrib import admin
from django.conf.urls import url


admin.autodiscover()

urlpatterns = [
    url(r'^', admin.site.urls),
]



# Copyright Collab 2015-2016
# See LICENSE for details.

"""
Tests for the :py:mod:`admin_footer` templatetag.
"""

from __future__ import unicode_literals

from django.conf import settings
from django.template import base, loader
from django.template.context import Context
from django.test import TestCase, RequestFactory

from django.contrib.auth.models import User


class FooterTagTests(TestCase):
    """
    Tests for the :py:mod:`~admin_footer.templatetags.footer` template tag.
    """
    def _renderTemplate(self, version=False):
        data = settings.ADMIN_FOOTER_DATA
        if version is True:
            data.pop('version', None)
        tpl = loader.get_template('admin_footer/footer.html')
        return tpl.render(data)

    def assertFooter(self, context, output,
                     template='{% admin_footer %}'):
        """
        :param template:
        :param context:
        :param output:
        """
        template = base.Template('{% load footer %}' + template)
        ctx = Context(context)
        self.assertEqual(template.render(ctx), output)

    def test_footerAuthenticated(self):
        """
        Using the tag with admin rights returns the footer with a version nr.
        """
        user = User.objects.create_superuser('test',
            'test@koo.ls', 'top_secret')
        request = RequestFactory().post('/', user=user)
        request.user = user
        context = {'request': request}
        output = self._renderTemplate()

        self.assertFooter(context, output)

    def test_footerAnonymous(self):
        """
        Using the tag as anonymous user excludes the version nr in the footer.
        """
        user = User.objects.create_user('test',
            'test@koo.ls', 'top_secret')
        request = RequestFactory().post('/', user=user)
        request.user = user
        context = {'request': request}
        output = self._renderTemplate(True)

        self.assertFooter(context, output)

    def test_rejectArguments(self):
        """
        Passing arguments to the tag raises a `TemplateSyntaxError`.
        """
        try:
            base.Template('{% load footer %}{% admin_footer foo %}')
        except base.TemplateSyntaxError as e:
            self.assertEqual(str(e),
                'admin_footer tag does not accept any argument(s): foo')




#!/usr/bin/env python
# Copyright Collab 2015-2016
# See LICENSE for details.

import os
import sys
from setuptools import setup, find_packages

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# get version nr
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__),
    'admin_footer')))
from admin_footer import version  # flake8: noqa
sys.path.pop(0)

setup(
    name='django-admin-footer',
    packages=find_packages(),
    include_package_data=True,
    version=version,
    description='Templatetag to render footer in Django admin.',
    long_description=README,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Software Development',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    author='Collab',
    author_email='info@collab.nl',
    url='http://github.com/collab-project/django-admin-footer',
    license='MIT'
)



# Copyright Collab 2015-2016
# See LICENSE for details.

"""
Tests for the :py:mod:`admin_footer` versioning.
"""

from __future__ import unicode_literals

from django.test import TestCase

from admin_footer import get_version


class VersionTestCase(TestCase):
    """
    Tests for :py:mod:`~encode` versioning information.
    """
    def test_regularVersion(self):
        """
        :py:func:`~encode.get_version` returns a string version without
        any beta tags, eg. `1.0.1`.
        """
        version = (1, 0, 1)
        self.assertEqual(get_version(version), '1.0.1')

    def test_betaVersion(self):
        """
        :py:func:`~encode.get_version` returns a string version with beta tags,
        eg. `1.2.3b1`.
        """
        version = (1, 2, 3, 'b1')
        self.assertEqual(get_version(version), '1.2.3b1')
